changeset 23873:49a433e2e78f

cosmetics: misc typo fixes
author diego
date Sat, 28 Jul 2007 14:28:38 +0000
parents 4d936284a5ec
children 702707dc7521
files DOCS/tech/playtree drivers/tdfx_vid.c liba52/bitstream.h liba52/liba52_changes.diff libmpdemux/demux_ogg.c libvo/vo_tdfx_vid.c libvo/vo_zr.c m_struct.c stream/stream_ftp.c
diffstat 9 files changed, 14 insertions(+), 14 deletions(-) [+]
line wrap: on
line diff
--- a/DOCS/tech/playtree	Sat Jul 28 14:27:55 2007 +0000
+++ b/DOCS/tech/playtree	Sat Jul 28 14:28:38 2007 +0000
@@ -51,7 +51,7 @@
 the child argument can be any entry in a list.
 To remove an entry from the tree use play_tree_remove. If the second arg (free_it)
 is true it will also free it, if the entry should be freed and the third
-arg is true it will also free the childs.
+arg is true it will also free the children.
 
 When your tree is ready you can then use play_tree_cleanup to remove all unuseful
 entries.
--- a/liba52/bitstream.h	Sat Jul 28 14:27:55 2007 +0000
+++ b/liba52/bitstream.h	Sat Jul 28 14:28:38 2007 +0000
@@ -42,7 +42,7 @@
 // alternative (faster) bitstram reader (reades upto 3 bytes over the end of the input)
 #define ALT_BITSTREAM_READER
 
-/* used to avoid missaligned exceptions on some archs (alpha, ...) */
+/* used to avoid misaligned exceptions on some archs (alpha, ...) */
 #if defined (ARCH_X86) || defined(ARCH_ARMV4L)
 #    define unaligned32(a) (*(uint32_t*)(a))
 #else
--- a/liba52/liba52_changes.diff	Sat Jul 28 14:27:55 2007 +0000
+++ b/liba52/liba52_changes.diff	Sat Jul 28 14:28:38 2007 +0000
@@ -96,7 +96,7 @@
 +// alternative (faster) bitstram reader (reades upto 3 bytes over the end of the input)
 +#define ALT_BITSTREAM_READER
 +
-+/* used to avoid missaligned exceptions on some archs (alpha, ...) */
++/* used to avoid misaligned exceptions on some archs (alpha, ...) */
 +#if defined (ARCH_X86) || defined(ARCH_ARMV4L)
 +#    define unaligned32(a) (*(uint32_t*)(a))
 +#else
--- a/libmpdemux/demux_ogg.c	Sat Jul 28 14:27:55 2007 +0000
+++ b/libmpdemux/demux_ogg.c	Sat Jul 28 14:28:38 2007 +0000
@@ -313,7 +313,7 @@
     // Calculate the timestamp
     if(pack->granulepos == -1)
       pack->granulepos = os->lastpos + (os->lastsize ? os->lastsize : 1);
-    // If we alredy have a timestamp it can be a syncpoint
+    // If we already have a timestamp it can be a syncpoint
     if(*pack->packet & PACKET_IS_SYNCPOINT)
       *flags = 1;
     *pts =  pack->granulepos/os->samplerate;
--- a/libvo/vo_tdfx_vid.c	Sat Jul 28 14:27:55 2007 +0000
+++ b/libvo/vo_tdfx_vid.c	Sat Jul 28 14:28:38 2007 +0000
@@ -149,7 +149,7 @@
   printf("Flip\n");
 #endif
   if(use_overlay) {
-    // TDFX_VID_OVERLAY_ON does nothing if the overlay is alredy on
+    // TDFX_VID_OVERLAY_ON does nothing if the overlay is already on
     if(!ioctl(tdfx_fd,TDFX_VID_OVERLAY_ON)) { // X11 killed the overlay :(
       if(ioctl(tdfx_fd,TDFX_VID_SET_OVERLAY,&tdfx_ov))
 	mp_msg(MSGT_VO, MSGL_ERR, "tdfx_vid: set_overlay failed\n");
--- a/libvo/vo_zr.c	Sat Jul 28 14:27:55 2007 +0000
+++ b/libvo/vo_zr.c	Sat Jul 28 14:28:38 2007 +0000
@@ -186,12 +186,12 @@
 	/* center the image, and stretch it as far as possible (try to keep
 	 * aspect) and check if it fits */
 	if (zr->image_width > zr->vc.maxwidth) {
-		mp_msg(MSGT_VO, MSGL_ERR, "zr: movie to be played is too wide, max width currenty %d\n", zr->vc.maxwidth);
+		mp_msg(MSGT_VO, MSGL_ERR, "zr: movie to be played is too wide, max width currently %d\n", zr->vc.maxwidth);
 		return 1;
 	}
 
 	if (zr->image_height > zr->vc.maxheight) {
-		mp_msg(MSGT_VO, MSGL_ERR, "zr: movie to be played is too high, max height currenty %d\n", zr->vc.maxheight);
+		mp_msg(MSGT_VO, MSGL_ERR, "zr: movie to be played is too high, max height currently %d\n", zr->vc.maxheight);
 		return 1;
 	}
 
--- a/m_struct.c	Sat Jul 28 14:27:55 2007 +0000
+++ b/m_struct.c	Sat Jul 28 14:28:38 2007 +0000
@@ -34,7 +34,7 @@
   // Check the struct fields
   for(i = 0 ; st->fields[i].name ; i++) {
     if(st->fields[i].type->flags & M_OPT_TYPE_INDIRECT) {
-      mp_msg(MSGT_CFGPARSER, MSGL_ERR,"Struct %s->%s: option type with the indirect flag are forbiden\n",st->name,st->fields[i].name);
+      mp_msg(MSGT_CFGPARSER, MSGL_ERR,"Struct %s->%s: Option types with the indirect flag are forbidden.\n",st->name,st->fields[i].name);
       return NULL;
     }
   }
--- a/drivers/tdfx_vid.c	Sat Jul 28 14:27:55 2007 +0000
+++ b/drivers/tdfx_vid.c	Sat Jul 28 14:28:38 2007 +0000
@@ -682,8 +682,8 @@
 static int tdfx_vid_overlay_on(void) {
   uint32_t vidcfg = tdfx_inl(VIDPROCCFG);
   //return 0;
-  if(vidcfg & (1<<8)) { // Overlay is alredy on
-    //printk(KERN_DEBUG "tdfx_vid: Overlay is alredy on\n");
+  if(vidcfg & (1<<8)) { // Overlay is already on
+    //printk(KERN_DEBUG "tdfx_vid: Overlay is already on.\n");
     return (-EFAULT); 
   }
   vidcfg |= (1<<8);
@@ -700,7 +700,7 @@
     return 0;
   }
 
-  printk(KERN_DEBUG "tdfx_vid: Overlay is alredy off\n");
+  printk(KERN_DEBUG "tdfx_vid: Overlay is already off.\n");
   return (-EFAULT); 
 }
 
--- a/stream/stream_ftp.c	Sat Jul 28 14:27:55 2007 +0000
+++ b/stream/stream_ftp.c	Sat Jul 28 14:28:38 2007 +0000
@@ -302,10 +302,10 @@
     return 0;
   }
 
-  // Check to see if the server doesn't alredy terminated the transfert
+  // Check to see if the server did not already terminate the transfer
   if(fd_can_read(p->handle, 0)) {
     if(readresp(p,rsp_txt) != 2)
-      mp_msg(MSGT_OPEN,MSGL_WARN, "[ftp] Warning the server didn't finished the transfert correctly: %s\n",rsp_txt);
+      mp_msg(MSGT_OPEN,MSGL_WARN, "[ftp] Warning the server didn't finished the transfer correctly: %s\n",rsp_txt);
     closesocket(s->fd);
     s->fd = -1;
   }
@@ -423,7 +423,7 @@
     return STREAM_ERROR;
   }
     
   // Set the transfert type
   resp = FtpSendCmd("TYPE I",p,rsp_txt);
   if(resp != 2) {
     mp_msg(MSGT_OPEN,MSGL_WARN, "[ftp] command 'TYPE I' failed: %s\n",rsp_txt);
@@ -423,7 +423,7 @@
   }
     
-  // Set the transfert type
+  // Set the transfer type
   resp = FtpSendCmd("TYPE I",p,rsp_txt);
   if(resp != 2) {